@@ -4,6 +4,8 @@
 # date:2021/12/8 10:53 上午
 # Copyright (C) 2021 The lesscode Team
 import logging
+
+from tornado.options import options
 from lesscode.db.base_sql_helper import BaseSqlHelper, echo_sql
 from lesscode.db.condition_wrapper import ConditionWrapper
 from lesscode.db.page import Page
@@ -168,7 +170,7 @@ class ElasticsearchHelper(BaseSqlHelper):
             info = hits[0].get("_source", {})
             info.update({"_id": hits[0].get("_id")})
             if aes_enable:
-                key = "haohaoxuexi"
+                key = options.aes_key
                 if aes_key:
                     key = aes_key
                 info["_id"] = AES.encrypt(key, info.get("_id"))
@@ -223,7 +225,7 @@ class ElasticsearchHelper(BaseSqlHelper):
                 info = x.get("_source", {})
                 info.update({"_id": x.get("_id")})
                 if aes_enable:
-                    key = "haohaoxuexi"
+                    key = options.aes_key
                     if aes_key:
                         key = aes_key
                     info["_id"] = AES.encrypt(key, info.get("_id"))
@@ -232,7 +234,7 @@ class ElasticsearchHelper(BaseSqlHelper):
 
     @echo_sql
     async def execute_fetch(self, param: str, sql: list = [], column: list = None, offset=0,
-                            size=100, sort: list = [], aes_enable=True, aes_key=None):
+                            size=100, sort: list = [], track_total_hits=None, aes_enable=True, aes_key=None):
         """
         查询多条数据
         :param sort: 排序
@@ -259,6 +261,7 @@ class ElasticsearchHelper(BaseSqlHelper):
         resp = await self.pool.search(
             index=param,
             body=body,
+            track_total_hits=track_total_hits,
             _source_includes=column
         )
         hits = resp.get("hits", {}).get("hits", [])
@@ -267,12 +270,15 @@ class ElasticsearchHelper(BaseSqlHelper):
             info = x.get("_source", {})
             info.update({"_id": x.get("_id")})
             if aes_enable:
-                key = "haohaoxuexi"
+                key = options.aes_key
                 if aes_key:
                     key = aes_key
                 info["_id"] = AES.encrypt(key, info.get("_id"))
             records.append(info)
-        return records
+        return {
+            "data_count": resp["hits"]["total"]["value"],
+            "data_list": records,
+        }
 
     @echo_sql
     async def execute_count(self, param: str, sql: list = []):
