@@ -38,8 +38,8 @@ class EsHelper:
             self.pool = pool
 
     async def send_es_post(self, bool_must_list=None, param_list=None, route_key="", sort_list=None, size=10,
-                     offset=0,
-                     track_total_hits=False):
+                           offset=0,
+                           track_total_hits=False):
         params = {
             "query": {
                 "bool": {
@@ -66,13 +66,14 @@ class EsHelper:
             logging.info(res)
         return res["hits"]
 
-    async def format_es_return(self, bool_must_list=None, param_list=None, route_key="", sort_list=None, size=10, offset=0,
-                         track_total_hits=False, is_need_es_score=False, is_need_decrypt_oralce=False, res=None):
+    async def format_es_return(self, bool_must_list=None, param_list=None, route_key="", sort_list=None, size=10,
+                               offset=0,
+                               track_total_hits=False, is_need_es_score=False, is_need_decrypt_oralce=False, res=None):
         if not res:
-            res = self.send_es_post(bool_must_list, param_list, route_key=route_key, sort_list=sort_list,
-                                    size=size,
-                                    offset=offset,
-                                    track_total_hits=track_total_hits)
+            res = await self.send_es_post(bool_must_list, param_list, route_key=route_key, sort_list=sort_list,
+                                          size=size,
+                                          offset=offset,
+                                          track_total_hits=track_total_hits)
 
         result_list = []
         for r in res["hits"]:
@@ -85,7 +86,7 @@ class EsHelper:
         return result_dict
 
     async def format_es_scan(self, bool_must_list=None, param_list=None, route_key="", scroll="5m", size=10000,
-                       is_need_decrypt_oralce=False, limit=None):
+                             is_need_decrypt_oralce=False, limit=None):
         logging.info("扫描开始，条件是{},查询字段是{}".format(json.dumps(bool_must_list), json.dumps(param_list)))
         skip = 0
         request_param = {
@@ -132,6 +133,20 @@ class EsHelper:
                 break
         return result_list
 
+    async def format_es_group(self, bool_must_list=None, route_key="", aggs=None):
+        params = {
+            "query": {
+                "bool": {
+                    "must": bool_must_list
+                }
+            },
+            "size": 0,
+            "aggs": aggs
+        }
+        res = self.pool.es_selector_way(url_func_str=self.pool.format_es_post_url, param_dict={
+            "route_key": route_key,
+        }, find_condition=params)
+        return res
 
 # ci = ConnectionInfo(dialect="esapi", name="es", host="120.92.209.197", port=9210, user="zhengyang",
 #                     password="158022", enable=True)
@@ -139,4 +154,3 @@ class EsHelper:
 # es = EsHelper(pool)
 # res = es.format_es_return([], ["_id"], "core.company_lite", None, 100, 0, False)
 # print(res)
-
